@@ -1,6 +1,6 @@
 /* -*- c++ -*- */
 /*
- * Copyright 2004 Free Software Foundation, Inc.
+ * Copyright 2004,2007 Free Software Foundation, Inc.
  * 
  * This file is part of GNU Radio
  * 
@@ -31,7 +31,7 @@ class gr_fft_vcc;
 typedef boost::shared_ptr<gr_fft_vcc> gr_fft_vcc_sptr;
 
 gr_fft_vcc_sptr
-gr_make_fft_vcc (int fft_size, bool forward, const std::vector<float> window);
+gr_make_fft_vcc (int fft_size, bool forward, const std::vector<float> window, bool shift=false);
 
 /*!
  * \brief Compute forward or reverse FFT.  complex vector in / complex vector out.
@@ -41,13 +41,15 @@ gr_make_fft_vcc (int fft_size, bool forward, const std::vector<float> window);
 class gr_fft_vcc : public gr_sync_block
 {
   friend gr_fft_vcc_sptr
-  gr_make_fft_vcc (int fft_size, bool forward, const std::vector<float> window);
+  gr_make_fft_vcc (int fft_size, bool forward, const std::vector<float> window, bool shift);
 
   unsigned int	   d_fft_size;
   std::vector<float>   d_window;
   gri_fft_complex *d_fft;
+  bool d_forward;
+  bool d_shift;
 
-  gr_fft_vcc (int fft_size, bool forward, const std::vector<float> window);
+  gr_fft_vcc (int fft_size, bool forward, const std::vector<float> window, bool shift);
 
  public:
   ~gr_fft_vcc ();
