@@ -1,5 +1,5 @@
 /*
- * Copyright 2002 Free Software Foundation, Inc.
+ * Copyright 2002,2007 Free Software Foundation, Inc.
  * 
  * This file is part of GNU Radio
  * 
@@ -33,6 +33,9 @@
 #include <qa_gr_vmcircbuf.h>
 #include <qa_gr_io_signature.h>
 #include <qa_gr_block.h>
+#include <qa_gr_flowgraph.h>
+#include <qa_gr_top_block.h>
+#include <qa_gr_hier_block2.h>
 #include <qa_gr_buffer.h>
 
 CppUnit::TestSuite *
@@ -43,6 +46,9 @@ qa_runtime::suite ()
   s->addTest (qa_gr_vmcircbuf::suite ());
   s->addTest (qa_gr_io_signature::suite ());
   s->addTest (qa_gr_block::suite ());
+  s->addTest (qa_gr_flowgraph::suite ());
+  s->addTest (qa_gr_top_block::suite ());
+  s->addTest (qa_gr_hier_block2::suite ());
   s->addTest (qa_gr_buffer::suite ());
   
   return s;
