@@ -30,7 +30,7 @@
 #
 #
 from gnuradio import gr, gru, blks, audio
-import usrp_dbid
+from usrpm import usrp_dbid
 from gnuradio import usrp, optfir
 from gnuradio import eng_notation
 from gnuradio.eng_option import eng_option
@@ -95,7 +95,7 @@ class app_flow_graph(stdgui.gui_flow_graph):
         self.reflevel = options.reflevel
         self.divbase = options.divbase
         self.division = options.division
-        self.audiodev = options.audio_dev
+        self.audiodev = options.audio_source
 
         # Low-pass cutoff for post-detector filter
         # Set to 100Hz usually, since lots of pulsars fit in this
@@ -295,7 +295,7 @@ class app_flow_graph(stdgui.gui_flow_graph):
         self.scope = ra_fftsink.ra_fft_sink_f (self, panel, 
            fft_size=int(options.fft_size), sample_rate=PULSAR_MAX_FREQ*2,
            title="Post-detector spectrum",  
-           cfunc=self.pulsarfunc, xydfunc=self.xydfunc, fft_rate=200)
+           ofunc=self.pulsarfunc, xydfunc=self.xydfunc, fft_rate=200)
 
         #
         # Tell scope we're looking from DC to PULSAR_MAX_FREQ
@@ -356,17 +356,8 @@ class app_flow_graph(stdgui.gui_flow_graph):
         self.second = gr.fir_filter_fff (int(p), second_filter)
         self.third = gr.fir_filter_fff (10, third_filter)
 
-        # Split complex USRP stream into a pair of floats
-        self.splitter = gr.complex_to_float (1);
-
-        # I squarer (detector)
-        self.multI = gr.multiply_ff();
-
-        # Q squarer (detector)
-        self.multQ = gr.multiply_ff();
-
-        # Adding squared I and Q to produce instantaneous signal power
-        self.adder = gr.add_ff();
+        # Detector
+        self.detector = gr.complex_to_mag_squared()
 
         self.enable_comb_filter = False
         # Epoch folder comb filter
@@ -402,25 +393,12 @@ class app_flow_graph(stdgui.gui_flow_graph):
         # Start connecting configured modules in the receive chain
         #
 
-        # Connect raw USRP to de-dispersion filter, complex->float splitter
-        self.connect(self.u, self.dispfilt, self.splitter)
+        # Connect raw USRP to de-dispersion filter, detector
+        self.connect(self.u, self.dispfilt, self.detector)
 
-        # Connect splitter outputs to multipliers
-        # First do I^2
-        self.connect((self.splitter, 0), (self.multI,0))
-        self.connect((self.splitter, 0), (self.multI,1))
-
-        # Then do Q^2
-        self.connect((self.splitter, 1), (self.multQ,0))
-        self.connect((self.splitter, 1), (self.multQ,1))
-
-        # Then sum the squares
-        self.connect(self.multI, (self.adder,0))
-        self.connect(self.multQ, (self.adder,1))
-
-        # Connect detector/adder output to FIR LPF
+        # Connect detector output to FIR LPF
         #  in two stages, followed by the FFT scope
-        self.connect(self.adder, self.first,
+        self.connect(self.detector, self.first,
             self.second, self.third, self.scope)
 
         # Connect audio output
@@ -1107,7 +1085,7 @@ class app_flow_graph(stdgui.gui_flow_graph):
         return(int(ntaps))
 
 def main ():
-    app = stdgui.stdapp(app_flow_graph, "RADIO ASTRONOMY PULSAR RECEIVER: $Revision: 6077 $", nstatus=1)
+    app = stdgui.stdapp(app_flow_graph, "RADIO ASTRONOMY PULSAR RECEIVER: $Revision: 6044 $", nstatus=1)
     app.MainLoop()
 
 if __name__ == '__main__':
