@@ -21,6 +21,9 @@
  */
 
 #include <cstdio>
+#include <string>
+#include <iostream>
+#include <fstream>
 #include <stdexcept>
 #include <cmath>
 #include "base.h"
@@ -47,7 +50,7 @@ fsm::fsm(const fsm &FSM)
   d_O=FSM.O();
   d_NS=FSM.NS();
   d_OS=FSM.OS();
-  d_PS=FSM.PS();
+  d_PS=FSM.PS(); // is this going to make a deep copy?
   d_PI=FSM.PI();
   d_TMi=FSM.TMi();
   d_TMl=FSM.TMl();
@@ -100,7 +103,6 @@ fsm::fsm(const char *name)
 
 
 
-
 //######################################################################
 //# Automatically generate the FSM from the generator matrix
 //# of a (n,k) binary convolutional code
@@ -241,17 +243,21 @@ fsm::fsm(int mod_size, int ch_length)
 //######################################################################
 void fsm::generate_PS_PI()
 {
-  d_PS.resize(d_I*d_S);
-  d_PI.resize(d_I*d_S);
+  d_PS.resize(d_S);
+  d_PI.resize(d_S);
 
   for(int i=0;i<d_S;i++) {
+    d_PS[i].resize(d_I*d_S); // max possible size
+    d_PI[i].resize(d_I*d_S);
     int j=0;
     for(int ii=0;ii<d_S;ii++) for(int jj=0;jj<d_I;jj++) {
       if(d_NS[ii*d_I+jj]!=i) continue;
-      d_PS[i*d_I+j]=ii;
-      d_PI[i*d_I+j]=jj;
+      d_PS[i][j]=ii;
+      d_PI[i][j]=jj;
       j++;
     }
+    d_PS[i].resize(j);
+    d_PI[i].resize(j);
   }
 }
 
@@ -278,9 +284,11 @@ void fsm::generate_TM()
       done = find_es(s);
       attempts ++;
     }
-    if (done == false)
+    if (done == false) {
       //throw std::runtime_error ("fsm::generate_TM(): FSM appears to be disconnected\n");
       printf("fsm::generate_TM(): FSM appears to be disconnected\n");
+      printf("state %d cannot be reached from all other states\n",s);
+    }
   }
 }
 
@@ -314,10 +322,92 @@ bool fsm::find_es(int es)
 
 
 
+//######################################################################
+//#  generate trellis representation of FSM as an SVG file
+//######################################################################
+void fsm::write_trellis_svg( std::string filename ,int number_stages)
+{
+   std::ofstream trellis_fname (filename.c_str());
+   if (!trellis_fname) {std::cout << "file not found " << std::endl ; exit(-1);}
+   const int TRELLIS_Y_OFFSET = 30;
+   const int TRELLIS_X_OFFSET = 20;
+   const int STAGE_LABEL_Y_OFFSET = 25;
+   const int STAGE_LABEL_X_OFFSET = 20;
+   const int STATE_LABEL_Y_OFFSET = 30;
+   const int STATE_LABEL_X_OFFSET = 5;
+   const int STAGE_STATE_OFFSETS = 10;
+//   std::cout << "################## BEGIN SVG TRELLIS PIC #####################" << std::endl;
+   trellis_fname << "<svg viewBox = \"0 0 200 200\" version = \"1.1\">" << std::endl;
+
+    for( int stage_num = 0;stage_num < number_stages;stage_num ++){
+    // draw states
+      for ( int state_num = 0;state_num < d_S ; state_num ++ ) {
+        trellis_fname << "<circle cx = \"" << stage_num * STAGE_STATE_OFFSETS + TRELLIS_X_OFFSET << 
+        "\" cy = \"" << state_num * STAGE_STATE_OFFSETS + TRELLIS_Y_OFFSET << "\" r = \"1\"/>" << std::endl;
+      //draw branches
+        if(stage_num != number_stages-1){
+          for( int branch_num = 0;branch_num < d_I; branch_num++){
+            trellis_fname << "<line x1 =\"" << STAGE_STATE_OFFSETS * stage_num+ TRELLIS_X_OFFSET  << "\" ";
+            trellis_fname << "y1 =\"" << state_num * STAGE_STATE_OFFSETS + TRELLIS_Y_OFFSET<< "\" ";
+            trellis_fname << "x2 =\"" <<  STAGE_STATE_OFFSETS *stage_num + STAGE_STATE_OFFSETS+ TRELLIS_X_OFFSET << "\" ";
+            trellis_fname << "y2 =\"" << d_NS[d_I * state_num + branch_num] * STAGE_STATE_OFFSETS + TRELLIS_Y_OFFSET << "\" ";
+            trellis_fname << " stroke-dasharray = \"3," <<  branch_num << "\" ";
+            trellis_fname << " stroke = \"black\" stroke-width = \"0.3\"/>" << std::endl;
+          }
+        }
+      }
+    }
+  // label the stages
+  trellis_fname << "<g font-size = \"4\" font= \"times\" fill = \"black\">" << std::endl;
+  for( int stage_num = 0;stage_num < number_stages ;stage_num ++){
+    trellis_fname << "<text x = \"" << stage_num * STAGE_STATE_OFFSETS + STAGE_LABEL_X_OFFSET << 
+      "\" y = \""  << STAGE_LABEL_Y_OFFSET  << "\" >" << std::endl;
+    trellis_fname << stage_num <<  std::endl;
+    trellis_fname << "</text>" << std::endl;
+  }
+  trellis_fname << "</g>" << std::endl;
+
+  // label the states
+  trellis_fname << "<g font-size = \"4\" font= \"times\" fill = \"black\">" << std::endl;
+  for( int state_num = 0;state_num < d_S ; state_num ++){
+    trellis_fname << "<text y = \"" << state_num * STAGE_STATE_OFFSETS + STATE_LABEL_Y_OFFSET << 
+      "\" x = \""  << STATE_LABEL_X_OFFSET  << "\" >" << std::endl;
+    trellis_fname << state_num <<  std::endl;
+    trellis_fname << "</text>" << std::endl;
+  }
+  trellis_fname << "</g>" << std::endl;
+
+
+  trellis_fname << "</svg>" << std::endl;
+//  std::cout << "################## END SVG TRELLIS PIC ##################### " << std::endl;
+  trellis_fname.close();
+}
 
 
 
 
 
 
+//######################################################################
+//# Write trellis specification to a text files,
+//# in the same format used when reading FSM files
+//######################################################################
+void fsm::write_fsm_txt(std::string filename)
+{
+   std::ofstream trellis_fname (filename.c_str());
+   if (!trellis_fname) {std::cout << "file not found " << std::endl ; exit(-1);}
+   trellis_fname << d_I << ' ' << d_S << ' ' << d_O << std::endl;
+   trellis_fname << std::endl;
+   for(int i=0;i<d_S;i++) {
+     for(int j=0;j<d_I;j++)  trellis_fname << d_NS[i*d_I+j] << ' ';
+     trellis_fname << std::endl;
+   }
+   trellis_fname << std::endl;
+   for(int i=0;i<d_S;i++) {
+     for(int j=0;j<d_I;j++) trellis_fname << d_OS[i*d_I+j] << ' ';
+     trellis_fname << std::endl;
+   }
+   trellis_fname << std::endl;
+   trellis_fname.close();
+}
 
